<?php

namespace EventPortal\AuthPassword\Http\Controllers;

use EventPortal\AuthPassword\Mail\PasswordReset;
use EventPortal\Domain\User\Models\User;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Str;

class ResetUserPasswordController extends Controller
{
    public function __construct()
    {
        $this->middleware('check-permission:' . config('auth-password.permissions.reset-password'));
    }

    public function __invoke(User $user): RedirectResponse
    {
        $user->update([
            'password_token' => Str::uuid(),
            'password_created_at' => null,
        ]);

        Mail::to($user->email)
            ->send(new PasswordReset($user->fresh()->password_token));

        toast()->success('Password reset email sent');

        return redirect()->route(config('auth-password.routes.password-reset.redirect'));
    }
}
